#
# SPEC-cpu.R, 17 Nov 14
#
# Data from:
# www.spec.org/cpu2006/results

source("config.r")


library("car")
library("relaimpo")



cpu2006=read.csv(paste0(root, "benchmark/cpu2006-results-20140206.csv"), as.is=TRUE)

# Memory numbers may be suffixed by:
# E unbuffered ecc memory
# F fully buffered ecc memory
# P parity, i.e., ecc memory
# R registered, i.e., ecc memory
mem2006=read.csv(paste0(root, "benchmark/cpu2006-memory.csv"), as.is=TRUE)
mem2006$ecc=substr(mem2006$mem_rate, nchar(mem2006$mem_rate), 100)
mem2006$mem_rate=as.numeric(sub("(E|F|P|R|U)$", "", x=mem2006$mem_rate))
# 8600 and 16000 are not supported rates, assume a typo
mem2006$mem_rate[mem2006$mem_rate == 8600]=8500
mem2006$mem_rate[mem2006$mem_rate == 16000]=17000

cpu2006=cbind(cpu2006, mem2006)
cpu2006$Test.Date=as.Date(paste0("01-", cpu2006$Test.Date), format="%d-%B-%Y")
start_date=as.Date("01-Jan-2006", format="%d-%B-%Y")
cpu2006=subset(cpu2006, Test.Date >= start_date)

cint=subset(cpu2006, Benchmark == "CINT2006")
cint$Benchmark=NULL
cint=subset(cint, Result > 0)
cint=subset(cint, mem_rate >= 3200)


PC2=subset(cint, mem_kind == "PC2")
PC3=subset(cint, mem_kind != "PC2")

# Fits a great model
# c_mod=glm(Baseline ~ Processor, data=cint)
# summary(c_mod)

# Remove detailed processor information
cint$Processor=sub("[0-9][0-9][0-9][0-9](K|L|M|S|T| EE| HE| SE| v2|V2| v3)*$", "", x=cint$Processor)

# Strip back to top level information
cint$main_proc=sub("([^ ]+ [^ ]+) .*$", "\\1", x=cint$Processor)

# Now nowhere near as good a fit
# c_mod=glm(Baseline ~ Processor, data=cint)
# summary(c_mod)


c_mod=glm(Result ~ Processor.MHz + mem_rate + mem_freq
    			, data=cint)
summary(c_mod)
vif(c_mod)

calc.relimp(c_mod, type = c("lmg", "last", "first", "betasq", "pratt"), rela = TRUE)
calc.relimp(c_mod)
t=boot.relimp(c_mod)
booteval.relimp(t)
plot(booteval.relimp(t))


c_mod=glm(Result ~ ecc+Processor.MHz + mem_rate + mem_freq
    			, data=cint)
summary(c_mod)

# Now nowhere near as good a fit
# c_mod=glm(Baseline ~ Processor, data=cint)
# summary(c_mod)

# Have to include more columns to get back close to where we were
c_mod=glm(Baseline ~ 
    (Processor + Processor.MHz)^2
    	, data=cint)
summary(c_mod)

# The Memory column contains lots of details
 c_mod=glm(Baseline ~ 
    Processor + Processor.MHz + Memory
    	, data=cint)
summary(c_mod)

# Break out the details
c_mod=glm(Baseline ~ 
    Processor + Processor.MHz + mem_rate + mem_freq
    	, data=cint)
summary(c_mod)


